@@ -1,4 +1,4 @@
-from .actions import transfer, add_contact, show_all_contact, show_contact_by_name, show_authorized_tokens, authorize_token, delete_contact, edit_contact
+from .actions import transfer, add_contact, show_all_contact, show_contact_by_name, delete_contact, edit_contact, show_account_info
 from .utils import contact_tool
 from .json_reader import JSONReader
 
@@ -8,9 +8,8 @@ __all__ = [
     'show_all_contact', 
     'show_contact_by_name', 
     'contact_tool',
-    'authorize_token',
-    'show_authorized_tokens',
     'JSONReader',
     'delete_contact',
-    'edit_contact'
+    'edit_contact',
+    'show_account_info'
 ]
\ No newline at end of file
