@@ -63,7 +63,7 @@ def edit_contact(name: str, address: str, step: any, **kwargs) -> dict:
         'next_action': None
     }
 
-def delete_contact(name: str, address: str, step: any, **kwargs) -> dict:
+def delete_contact(name: str, step: any, **kwargs) -> dict:
     redis_client = kwargs.get('redis_client')
     executor = kwargs.get('executor')
     code, res = redis_delete_contact(redis_client, executor, name)
