@@ -174,30 +174,28 @@ ERC20_APPROVE_ABI = """[{"constant":false,"inputs":[{"name":"_spender","type":"a
 
 ERC20_TRANSFER_ABI = """[{"constant":false,"inputs":[{"name":"recipient","type":"address"},{"name":"amount","type":"uint256"}],"name":"transfer","outputs":[{"name":"","type":"bool"}],"payable":false,"stateMutability":"nonpayable","type":"function"}]"""
 
+def record_transaction(redis_client, user_id: str, chain: str, tx_hash: str) -> None:
+    key = f"user:tx:{user_id}:{chain}"
+    redis_client.rpush(key, tx_hash)
+    print(f"Recorded transaction {tx_hash} on {chain} for user {user_id}")
+
 def mpc_transfer(default_address, destination, chain_raw, token_raw, token_address, amount):
     try:
         if chain_raw == 'base' and token_raw == 'usdc':
             transfer = default_address.transfer(amount, 'usdc', destination, gasless=True)
             transfer.wait()
-            print(f"Transfer complete: {transfer}")
-            print(f"Transfer transfer.status: {transfer.status}")
-            print(f"Transaction.Status.COMPLETE: {Transaction.Status.COMPLETE}")
-            print(f"transfer.status is Transaction.Status.COMPLETE: {transfer.status is Transaction.Status.COMPLETE}")
-            print(f"transfer.status == Transaction.Status.COMPLETE: {transfer.status == Transaction.Status.COMPLETE}")
             if str(transfer.status) == 'complete':
                 status = 200
                 transfer_status = 1
                 print(f"Transfer complete: {transfer.transaction_hash}")
                 print(f"Transfer successfully landed on-chain: {transfer.transaction_link}")
             else:
-                amount_to_transfer = convert_to_wei(float(amount), chain_raw, token_raw)
-                # increase_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
                 status = 500
                 transfer_status = 0
                 print(f"Transfer failed on-chain: {transfer.transaction_link}")
 
             info = {
-                "content": generate_tx_link_content(transfer.status, transfer.transaction_link),
+                "content": generate_tx_link_content(str(transfer.status), transfer.transaction_link),
                 "tx_hash": transfer.transaction_hash,
                 "chain": chain_raw,
                 "status": transfer_status,
@@ -213,7 +211,6 @@ def mpc_transfer(default_address, destination, chain_raw, token_raw, token_addre
             #     method="transfer",
             #     args={"to": destination, "value": amount_to_transfer}
             # )
-            # increase_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
             info = {
                 "content": f"In automatic mode, only USDC transfers on the Base mainnet are supported.",
                 "code": 500
@@ -224,7 +221,6 @@ def mpc_transfer(default_address, destination, chain_raw, token_raw, token_addre
             "content": f"{e}",
             "code": 500
         }
-        # increase_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
         return info
 
 def get_web3(providers, chain):
@@ -296,7 +292,31 @@ def transfer(receiver: str, amount: float, step: any, chain: str = "base", token
         return handle_manual_transfer(w3, eth_w3, executor, receiver, amount, token_address, redis_client, chain_raw, token_raw)
 
 def handle_auto_transfer(w3: Web3, eth_w3, mpc_address, executor, receiver, amount, token_address, spender_address, sender_address, control_contract, private_key, redis_client, chain_raw, token_raw, blockchain_explore, executor_balance):
-    if token_raw != 'usdc':
+    
+    if token_raw == 'usdc' and chain_raw == 'base':
+        amount_to_transfer = convert_to_wei(float(amount), chain_raw, token_raw)
+        try:
+            decrease_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
+        except Exception as e:
+            print(f"Exception occurred: {e}", flush=True)
+            return {'result': {"content": f"{e}", "code": 500}, 'action': None, 'next_action': None}
+        try:
+            code, receiver_address = get_contact_address(redis_client, executor, receiver, eth_w3)
+            if code != 200:
+                return {'result': {"content": f"Cannot find {receiver} on contacts", "code": 420}, 'action': None, 'next_action': None}
+
+            to = w3.to_checksum_address(receiver_address)
+            executor = w3.to_checksum_address(executor)
+
+            print(f"to: {to}, executor: {executor}")
+            info = mpc_transfer(mpc_address, to, chain_raw, token_raw, token_address, amount)
+            if info['code'] != 200:
+                increase_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
+            return {'result': info, 'action': None, 'next_action': None}
+        except Exception as e:
+            increase_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
+            return handle_transaction_error(e, control_contract, w3)
+    else:
         token = token_raw.upper()
         if token_raw in ['btc', 'cbbtc', 'wbtc']:
             if chain_raw == 'base':
@@ -304,54 +324,7 @@ def handle_auto_transfer(w3: Web3, eth_w3, mpc_address, executor, receiver, amou
             else:
                 token = 'WBTC'
         return {'result': {"code": 500, "content": f"Transfers of the current currency({token}) are not supported in automatic mode."}, 'action': None, 'next_action': None}
-    else:
-        # token_contract = w3.eth.contract(address=token_address, abi=ALLOWANCE_ABI)
-        # allowance = token_contract.functions.allowance(Web3.to_checksum_address(executor), spender_address).call()
-        # allowance_normalized = convert_to_value(allowance, chain_raw, token_raw)
-        # print(f"allowance_normalized: {float(allowance_normalized)}")
-        amount_to_transfer = convert_to_wei(float(amount), chain_raw, token_raw)
-        try:
-            decrease_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
-        except Exception as e:
-            print(f"Exception occurred: {e}", flush=True)
-            return {'result': {"content": f"{e}", "code": 500}, 'action': None, 'next_action': None}
         
-        # if float(allowance_normalized) < float(amount):
-        #     return handle_insufficient_allowance(w3, eth_w3, executor, receiver, amount, spender_address, token_address, chain_raw, token_raw, redis_client)
-
-        code, receiver_address = get_contact_address(redis_client, executor, receiver, eth_w3)
-        if code != 200:
-            return {'result': {"content": f"Cannot find {receiver} on contacts", "code": 420}, 'action': None, 'next_action': None}
-
-        # amount_to_transfer = convert_to_wei(float(amount), chain_raw, token_raw)
-        to = w3.to_checksum_address(receiver_address)
-        executor = w3.to_checksum_address(executor)
-
-        print(f"to: {to}, executor: {executor}")
-        
-        try:
-            info = mpc_transfer(mpc_address, to, chain_raw, token_raw, token_address, amount)
-
-            if info['code'] != 200:
-                increase_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
-
-            return {'result': info, 'action': None, 'next_action': None}
-            # can_send, tx_hash = maybe_send_transaction(w3, control_contract, sender_address, token_address, executor, to, amount_to_transfer, private_key, chain_raw, executor_balance)
-            # if can_send:
-            #     tx_receipt = w3.eth.wait_for_transaction_receipt(tx_hash)
-            #     status = 200 if tx_receipt['status'] == 1 else 500
-            #     info = {
-            #         "content": generate_markdown_content(tx_receipt['status'], tx_hash.hex(), blockchain_explore),
-            #         "tx_hash": tx_hash.hex(),
-            #         "chain": chain_raw,
-            #         "status": tx_receipt['status'],
-            #         "code": status
-            #     }
-            #     return {'result': info, 'action': None, 'next_action': None}
-            # else:
-            #     return {'result': {"code": 402, "content": "Your account balance is insufficient. Please top up first, or apply to join the credit list to receive $5 of Ardio Credit."}, 'action': None, 'next_action': None}
-        except Exception as e:
-            return handle_transaction_error(e, control_contract, w3)
 
 def handle_manual_transfer(w3: Web3, eth_w3, executor, receiver, amount, token_address, redis_client, chain_raw, token_raw):
     active_chain_key = f"user:active_chain:{executor}"
@@ -487,7 +460,7 @@ def generate_markdown_content(status, hash_value, blockchain_explore):
 
 
 def generate_tx_link_content(status, tx_link):
-    status_text = "successful" if status is Transaction.Status.COMPLETE else "failed"
+    status_text = "successful" if status == 'complete' else "failed"
     return f"Transfer {status_text}. You can check the transaction on [blockchain explorer]({tx_link})"
 
 
