@@ -136,7 +136,7 @@ def generate_markdown_table(assets):
     
     # Generate rows for each asset entry
     rows = [
-        f"| {asset['chain']} | {asset['token']} | {asset['amount']} |"
+        f"| {asset['chain'].upper()} | {asset['token'].upper()} | {convert_to_value(asset['amount'], 6)} |"
         for asset in assets
     ]
     
@@ -161,15 +161,19 @@ def generate_complete_markdown(user_address, ai_balance, assets):
     # Header with user address and AI balance
     header = (
         f"**Account address:** `{user_address}`\n"
-        f"**AI remain balance:** {ai_balance}\n"
+        f"**AI remain balance:** {convert_to_value(ai_balance, 6)}\n"
         f"**Assets:**\n\n"
     )
     
     # Define the table structure
     table_header = "| Chain | Token | Amount |\n|-------|-------|--------|\n"
-    rows = [f"| {asset['chain']} | {asset['token']} | {asset['amount']} |" for asset in assets]
+    rows = [f"| {asset['chain'].upper()} | {asset['token'].upper()} | {convert_to_value(asset['amount'], 6)} |" for asset in assets]
     table = table_header + "\n".join(rows)
     
     # Combine the header and table into the final Markdown output
     markdown_output = header + table
-    return markdown_output
\ No newline at end of file
+    return markdown_output
+
+def convert_to_value(amount, decimal):
+    amount = amount / (10 ** decimal)
+    return float(amount)
\ No newline at end of file
