@@ -131,7 +131,9 @@ def redis_show_contact(redis_client, user: str, name: str = None) -> Tuple[int,
     try:
         contact_mapping = get_user_contacts_mapping(redis_client, user)
         if name:
-            contact_mapping = {name: contact_mapping.get(name, {})}
+            contact_mapping = {name: contact_mapping.get(name, None)}
+            if not contact_mapping[name]:
+                return 404, f"Cannot find {name} in contacts."
         result = generate_markdown(contact_mapping)
     except Exception as e:
         logger.error(f"Error fetching contacts: {e}")
